##  Scope of the Integration
  * Process to business context fact sheets: The integration synchronizes process diagrams, navigation maps, and value chains from SAP Signavio as business context fact sheets in SAP LeanIX. You can configure the integration to map processes to specific subtypes of business context fact sheets.
  * Other fact sheets with dictionary items: Application, business capability, and organization fact sheets—along with their subtypes—can be synced with corresponding SAP Signavio dictionary items. If you need to sync additional fact sheet types, you can have them configured for the integration by contacting [SAP LeanIX Support![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support") or [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/").
  * Fact sheet attributes and dictionary fields: You can synchronize the necessary fact sheet attributes and dictionary fields based on your specific needs. The integration supports the synchronization of:
    * Scalar fields (e.g., text, numbers)
    * Single-select and multi-select fields
    * Date fields
    * Subscriptions and subscription roles
    * Tags and tag groups
  * Additionally, links to the process diagrams and their visuals from SAP Signavio are added to the resources tab of the fact sheet.
